@@ -47,6 +47,26 @@ class Resource:
     STOP_WORDS = STOPWORDS
     SEARCH_TERMS = SEARCHTERMS
 
+    @staticmethod
+    def get_all_sources():
+        test = Resource.__dict__.keys()
+        variables = []
+        for item in test:
+            if str(item).__contains__("_SOURCES"):
+                variables.append(item)
+        return variables
+
+    @staticmethod
+    def get_source(sourceTerm):
+        sources = Resource.get_all_sources()
+        for src in sources:
+            srcSmall = str(src).lower()
+            sourceTermSmall = str(sourceTerm).lower()
+            if srcSmall.__contains__(sourceTermSmall):
+                mainSource = getattr(Resource, src)
+                source_list = get_resource(mainSource)
+                return source_list
+
 def get_resource(resource):
     """Uses generator to return next useragent in saved file
     """
@@ -81,7 +101,8 @@ def get_search_terms():
     return get_resource_not_url(SEARCHTERMS)
 
 def get_random_user_agent():
-    return get_resource_not_url(Resource.USER_AGENTS)
+    all = get_resource_not_url(Resource.USER_AGENTS)
+    return LIST.get_random(all, False)
 
 def get_stopwords():
     return get_resource_not_url(STOPWORDS)
